#import <Foundation/Foundation.h>
#import "iCore.h"
#import <AVFoundation/AVFoundation.h>
@class B4I;
@class B4IList;
/**
* The BarcodeScanner uses the device camera to scan for barcode codes.
* The Ready event will be raised after the scanner is initialized.
* Once the scanner is ready you can call Start to start scanning.
* The Detected event will be raised whenever a code is detected.
*/
//~version:1.20
//~shortname:BarcodeScanner
//~event:Ready (Success As Boolean)
//~event:Detected (Codes As List)
//~dependson:AVFoundation.framework
@interface iBarcode : NSObject
@property (nonatomic, readonly)NSString * TYPE_QR;
@property (nonatomic, readonly)NSString * TYPE_UPCE;
@property (nonatomic, readonly)NSString * TYPE_39;
@property (nonatomic, readonly)NSString * TYPE_39Mod43;
@property (nonatomic, readonly)NSString * TYPE_EAN13;
@property (nonatomic, readonly)NSString * TYPE_EAN8;
@property (nonatomic, readonly)NSString * TYPE_93;
@property (nonatomic, readonly)NSString * TYPE_128;
@property (nonatomic, readonly)NSString * TYPE_PDF417;
@property (nonatomic, readonly) int TORCH_OFF;
@property (nonatomic, readonly) int TORCH_ON;
@property (nonatomic, readonly) int TORCH_AUTO;
//iOS 8+ only
@property (nonatomic, readonly)NSString * TYPE_Interleaved2of5;
//iOS 8+ only
@property (nonatomic, readonly)NSString * TYPE_ITF14;
//iOS 8+ only
@property (nonatomic, readonly)NSString * TYPE_DataMatrix;
//Gets or sets the camera torch mode. One of the TORCH constants.
@property (nonatomic)int TorchMode;
//Gets or sets whether the user can tap on the screen to focus the camera. Default value is true.
@property (nonatomic)BOOL AllowTapToFocus;
/**
* Initializes the scanner. The Ready event will be raised when the scanner is ready.
*EventName - Sets the subs that handle the events.
*View - The preview panel.
*/
- (void)Initialize:(B4I *)bi :(NSString *)EventName :(UIView *)View;
//Similar to Initialize. Will only detect codes that match one of the types from the Types list (or array).
- (void)Initialize2:(B4I *)bi :(NSString *)EventName :(UIView *)View :(B4IList *)Types;
//Resizes the preview frame to match the preview view.
- (void)Resize;
//Starts scanning.
- (void)Start;
//Stops scanning.
- (void)Stop;
@end

//~shortname:BarcodeCode
//~objectwrapper:AVMetadataMachineReadableCodeObject*
@interface B4IBarcodeCode:B4IObjectWrapper
//Returns the code string value.
@property (nonatomic, readonly) NSString *Value;
@end